@@ -11,13 +11,15 @@ use File::Spec;
 use List::Util qw/any/;
 use Set::Functional qw/difference intersection/;
 use Data::Validator;
+use Text::CSV_XS;
+use Encode qw/encode decode/;
 
 use Class::Accessor::Lite (
     new => 1,
     ro  => [ qw(conf dbh) ],
 );
 
-our $VERSION = "0.05";
+our $VERSION = "0.06";
 
 sub load {
     my $v = Data::Validator->new(
@@ -33,12 +35,17 @@ sub load {
     my $load_opt = exists $self->conf->{load_opt} ? $self->conf->{load_opt} : undef;
 
     for my $fixture (@tables) {
+
         $loader->load_fixture(
-            File::Spec->catfile($self->conf->{fixture_path}, "$fixture.yaml"),
+            File::Spec->catfile($self->conf->{fixture_path}, $fixture . '.' . $self->conf->{fixture_type}),
+            format => $self->conf->{fixture_type},
+            csv_opt => +{ binary => 1 },
         ) unless $load_opt;
 
         $loader->load_fixture(
-            File::Spec->catfile($self->conf->{fixture_path}, "$fixture.yaml"),
+            File::Spec->catfile($self->conf->{fixture_path}, $fixture . '.' . $self->conf->{fixture_type}),
+            format => $self->conf->{fixture_type},
+            csv_opt => +{ binary => 1 },
             $load_opt => 1,
         ) if $load_opt;
     }
@@ -51,14 +58,19 @@ sub load_all {
 
 sub create {
     my $v = Data::Validator->new(
-        tables    => +{ isa => 'ArrayRef[Str]' },
+        tables      => +{ isa => 'ArrayRef[Str]' },
         create_file => +{ isa => 'Bool', default => 1 },
     )->with(qw/Method  StrictSequenced/);
-    my($self, $args) = $v->validate(@_);
+    my ($self, $args) = $v->validate(@_);
 
     my @result;
     for my $data ($self->_build_create_data($args->{tables})) {
-        push @result, [$self->_make_fixture_yaml(+{%$data, create_file => $args->{create_file}})];
+        push @result, [$self->_make_fixture_yaml(+{%$data, create_file => $args->{create_file}})]
+            if $self->conf->{fixture_type} eq 'yaml';
+
+        push @result, [$self->_make_fixture_csv(+{%$data, create_file => $args->{create_file}})]
+            if $self->conf->{fixture_type} eq 'csv';
+
     }
 
     return @result;
@@ -66,7 +78,7 @@ sub create {
 
 sub create_all {
     my $v = Data::Validator->new(
-        create_file => +{ isa => 'Bool', default => 1 },
+        create_file  => +{ isa => 'Bool', default => 1 },
     )->with(qw/Method/);
     my($self, $args) = $v->validate(@_);
 
@@ -85,10 +97,11 @@ sub fixtures {
     my ($self,) = @_;
 
     my @all_fixtures = $self->_all_fixtures;
+    my $type = $self->conf->{fixture_type};
     my %table2fixture
         = map {
             my $tmp = basename($_);
-            $tmp =~ s/\.yaml$//;
+            $tmp =~ s/\.$type$//;
             $tmp => basename($_);
         } @all_fixtures;
 
@@ -102,9 +115,11 @@ sub tables {
     my ($self,) = @_;
 
     my @fixtures = $self->fixtures;
+    my $type = $self->conf->{fixture_type};
+
     my @tables = map {
         my $tmp = basename($_);
-        $tmp =~ s/\.yaml$//;
+        $tmp =~ s/\.$type$//;
         $tmp
     } @fixtures;
 
@@ -114,7 +129,7 @@ sub tables {
 sub _all_fixtures {
     my ($self,) = @_;
 
-    return glob(File::Spec->catfile($self->conf->{fixture_path}, '*.yaml'));
+    return glob(File::Spec->catfile($self->conf->{fixture_path}, '*.' . $self->conf->{fixture_type}));
 }
 
 sub _difference_ignore_tables {
@@ -199,6 +214,51 @@ sub _make_fixture_yaml {
     );
 }
 
+sub _make_fixture_csv {
+    my $v = Data::Validator->new(
+        table     => 'Str',
+        columns   => 'ArrayRef[Str]',
+        sql       => 'Str',
+        create_file => +{ isa => 'Bool', default => 1 },
+    )->with(qw/Method/);
+    my($self, $args) = $v->validate(@_);
+
+    my %tmp_args     = %$args;
+    my @columns      = @{$args->{columns}};
+    my $fixture_path = File::Spec->catfile($self->conf->{fixture_path}, "$tmp_args{table}.csv");
+
+    my @data = @{$args->{columns}};
+    my $rows = $self->dbh->selectall_arrayref( $args->{sql}, +{ Slice => +{} } );
+
+    my $csv_builder = Text::CSV_XS->new(+{ binary => 1 });
+    $csv_builder->combine(@columns);
+
+    my $csv = $csv_builder->string . "\n";
+
+    for my $row (@$rows) {
+        my @values;
+        for my $key (@data) {
+            my $value = $row->{$key};
+            push @values, decode('utf8', $value)
+                unless utf8::is_utf8($value);
+
+            push @values, $value
+                if utf8::is_utf8($value);
+        }
+        $csv_builder->combine(@values);
+        $csv = $csv . $csv_builder->string . "\n";
+    }
+
+    if ($args->{create_file}) {
+        open my $file, '>', $fixture_path;
+        print $file encode('utf8', $csv);
+        close $file;
+    }
+    else {
+        return $csv;
+    }
+}
+
 1;
 __END__
 
@@ -219,6 +279,7 @@ DBIx::Fixture::Admin - facilitate data management by the fixtures
     my $admin = DBIx::Fixture::Admin->new(
         conf => +{
             fixture_path  => "./fixture/",
+            fixture_type  => "yaml",
             driver        => "mysql",
             load_opt      => "update",
             ignore_tables => ["user_.*", ".*_log"]  # ignore management
